@@ -161,7 +161,7 @@ pub enum WebsocketResponse<T> {
 impl<T> WebsocketResponse<T> {
     pub fn get_id(&self) -> Option<u64> {
         match self {
-            Self::Success(res) => res.id.to_owned(),
+            Self::Success(res) => Some(res.id.to_owned()),
             Self::Error(res) => res.id.to_owned(),
         }
     }
@@ -170,7 +170,7 @@ impl<T> WebsocketResponse<T> {
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct WebsocketSuccessResponse<T> {
     /// (WebSocket only) ID provided in the request that prompted this response
-    pub id: Option<RequestId>,
+    pub id: RequestId,
     /// (WebSocket only) The value response indicates a direct response to an API request. Asynchronous notifications use a different value such as ledgerClosed or transaction.
     pub r#type: Option<String>,
     /// The result of the query; contents vary depending on the command.
@@ -206,7 +206,7 @@ pub struct JsonRPCSuccessResponse<T> {
     pub forwarded: Option<bool>,
 }
 
-#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 pub struct SignerList {
     #[serde(rename = "SignerEntries")]
     pub signer_entries: Vec<SignerEntry>,
@@ -214,7 +214,7 @@ pub struct SignerList {
     pub signer_quorum: u32,
 }
 
-#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 pub struct SignerEntry {
     #[serde(rename = "Account")]
     pub account: String,
@@ -222,7 +222,7 @@ pub struct SignerEntry {
     pub signer_weight: u16,
 }
 
-#[derive(Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 #[serde(untagged)]
 pub enum CurrencyAmount {
     XRP(BigInt),
@@ -248,28 +248,28 @@ impl Default for CurrencyAmount {
     }
 }
 
-#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 pub struct IssuedCurrencyAmount {
     pub value: Decimal,
     pub currency: String,
     pub issuer: Address,
 }
 
-#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 pub struct TransactionEntryRequest {
     pub tx_hash: Option<String>,
     pub ledger_index: Option<u64>,
     pub ledger_hash: Option<String>,
 }
 
-#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 pub struct TransactionEntryResponse {
     pub tx_json: Option<Value>,
     pub ledger_index: Option<u64>,
     pub ledger_hash: Option<String>,
 }
 
-#[derive(Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 #[serde(tag = "LedgerEntryType")]
 pub enum LedgerEntry {
     Unknown,
@@ -283,7 +283,7 @@ impl Default for LedgerEntry {
     }
 }
 
-#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 #[serde(rename_all = "PascalCase")]
 pub struct AccountRoot {
     /// The identifying (classic) address of this account.
@@ -319,7 +319,7 @@ pub struct AccountRoot {
     pub transfer_rate: Option<u32>,
 }
 
-#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq, Clone)]
 #[serde(rename_all = "PascalCase")]
 pub struct Check {
     /// The sender of the Check. Cashing the Check debits this address's balance.
