@@ -1,6 +1,8 @@
 use super::Address;
 use serde::{Deserialize, Serialize};
+use serde_with::skip_serializing_none;
 
+#[skip_serializing_none]
 #[derive(Serialize, Deserialize, Clone, Debug)]
 pub enum SubscribeRequest {
     #[serde(rename = "accounts")]
@@ -9,6 +11,7 @@ pub enum SubscribeRequest {
     Streams(Vec<String>),
 }
 
+#[skip_serializing_none]
 #[derive(Serialize, Deserialize, Clone, Debug)]
 #[serde(tag = "type")]
 pub enum SubscriptionEvent {
@@ -16,6 +19,7 @@ pub enum SubscriptionEvent {
     LedgerClosed(LedgerClosed),
 }
 
+#[skip_serializing_none]
 #[derive(Serialize, Deserialize, Clone, Debug)]
 pub struct LedgerClosed {
     /// The identifying hash of the ledger version that was closed.
