@@ -1,7 +1,9 @@
 use crate::transaction::types::Transaction;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
+use serde_with::skip_serializing_none;
 
+#[skip_serializing_none]
 #[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
 pub struct TxRequest {
     /// The 256-bit hash of the transaction, as hex.
@@ -10,6 +12,7 @@ pub struct TxRequest {
     pub binary: Option<bool>,
 }
 
+#[skip_serializing_none]
 #[derive(Default, Debug, Serialize, Deserialize, Eq, PartialEq)]
 pub struct TxResponse {
     /// The SHA-512 hash of the transaction
